@@ -344,6 +344,12 @@ namespace Aws
             return *this;
         }
 
+        Mqtt5ClientBuilder &Mqtt5ClientBuilder::WithSocketOptions(Crt::Io::SocketOptions socketOptions) noexcept
+        {
+            m_options->WithSocketOptions(std::move(socketOptions));
+            return *this;
+        }
+
         Mqtt5ClientBuilder &Mqtt5ClientBuilder::WithHttpProxyOptions(
             const Crt::Http::HttpClientConnectionProxyOptions &proxyOptions) noexcept
         {
@@ -571,18 +577,20 @@ namespace Aws
                 m_options->WithConnectOptions(m_connectOptions);
             }
 
+            bool proxyOptionsSet = false;
+
             if (m_websocketConfig.has_value())
             {
                 auto websocketConfig = m_websocketConfig.value();
                 auto signerTransform = [websocketConfig](
                                            std::shared_ptr<Crt::Http::HttpRequest> req,
-                                           const Crt::Mqtt::OnWebSocketHandshakeInterceptComplete &onComplete) {
+                                           const Crt::Mqtt::OnWebSocketHandshakeInterceptComplete &onComplete)
+                {
                     // it is only a very happy coincidence that these function signatures match. This is the callback
                     // for signing to be complete. It invokes the callback for websocket handshake to be complete.
                     auto signingComplete =
-                        [onComplete](const std::shared_ptr<Aws::Crt::Http::HttpRequest> &req1, int errorCode) {
-                            onComplete(req1, errorCode);
-                        };
+                        [onComplete](const std::shared_ptr<Aws::Crt::Http::HttpRequest> &req1, int errorCode)
+                    { onComplete(req1, errorCode); };
 
                     auto signerConfig = websocketConfig.CreateSigningConfigCb();
 
@@ -595,13 +603,20 @@ namespace Aws
                 if (useWebsocketProxyOptions)
                 {
                     m_options->WithHttpProxyOptions(m_websocketConfig->ProxyOptions.value());
+                    proxyOptionsSet = true;
                 }
                 else if (m_proxyOptions.has_value())
                 {
                     m_options->WithHttpProxyOptions(m_proxyOptions.value());
+                    proxyOptionsSet = true;
                 }
             }
 
+            if (m_proxyOptions.has_value() && !proxyOptionsSet)
+            {
+                m_options->WithHttpProxyOptions(m_proxyOptions.value());
+            }
+
             return Crt::Mqtt5::Mqtt5Client::NewMqtt5Client(*m_options, m_allocator);
         }
 
@@ -611,7 +626,10 @@ namespace Aws
             AWS_ZERO_STRUCT(m_passwordStorage);
         }
 
-        Aws::Iot::Mqtt5CustomAuthConfig::~Mqtt5CustomAuthConfig() { aws_byte_buf_clean_up(&m_passwordStorage); }
+        Aws::Iot::Mqtt5CustomAuthConfig::~Mqtt5CustomAuthConfig()
+        {
+            aws_byte_buf_clean_up(&m_passwordStorage);
+        }
 
         Aws::Iot::Mqtt5CustomAuthConfig::Mqtt5CustomAuthConfig(const Mqtt5CustomAuthConfig &rhs)
         {
@@ -683,17 +701,35 @@ namespace Aws
             return *this;
         }
 
-        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetAuthorizerName() { return m_authorizerName; }
+        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetAuthorizerName()
+        {
+            return m_authorizerName;
+        }
 
-        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetUsername() { return m_username; }
+        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetUsername()
+        {
+            return m_username;
+        }
 
-        const Crt::Optional<Crt::ByteCursor> &Mqtt5CustomAuthConfig::GetPassword() { return m_password; }
+        const Crt::Optional<Crt::ByteCursor> &Mqtt5CustomAuthConfig::GetPassword()
+        {
+            return m_password;
+        }
 
-        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetTokenKeyName() { return m_tokenKeyName; }
+        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetTokenKeyName()
+        {
+            return m_tokenKeyName;
+        }
 
-        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetTokenValue() { return m_tokenValue; }
+        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetTokenValue()
+        {
+            return m_tokenValue;
+        }
 
-        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetTokenSignature() { return m_tokenSignature; }
+        const Crt::Optional<Crt::String> &Mqtt5CustomAuthConfig::GetTokenSignature()
+        {
+            return m_tokenSignature;
+        }
 
         Mqtt5CustomAuthConfig &Aws::Iot::Mqtt5CustomAuthConfig::WithAuthorizerName(Crt::String authName)
         {
